Class: Dnsimple::Struct::Certificate

Inherits:
Base
  • Object
show all
Defined in:
lib/dnsimple/struct/certificate.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#initialize

Constructor Details

This class inherits a constructor from Dnsimple::Struct::Base

Instance Attribute Details

#alternate_namesArray<String>

Returns The certificate alternate names.

Returns:

  • (Array<String>)

    The certificate alternate names.



19
20
21
# File 'lib/dnsimple/struct/certificate.rb', line 19

def alternate_names
  @alternate_names
end

#authority_identifierString

Returns The Certificate Authority (CA) that issued the certificate.

Returns:

  • (String)

    The Certificate Authority (CA) that issued the certificate.



31
32
33
# File 'lib/dnsimple/struct/certificate.rb', line 31

def authority_identifier
  @authority_identifier
end

#auto_renewBoolean

Returns True if the certificate is set to auto-renew on expiration.

Returns:

  • (Boolean)

    True if the certificate is set to auto-renew on expiration.



34
35
36
# File 'lib/dnsimple/struct/certificate.rb', line 34

def auto_renew
  @auto_renew
end

#common_nameString

Returns The certificate common name.

Returns:

  • (String)

    The certificate common name.



16
17
18
# File 'lib/dnsimple/struct/certificate.rb', line 16

def common_name
  @common_name
end

#contact_idInteger

Returns The associated contact ID.

Returns:

  • (Integer)

    The associated contact ID.



13
14
15
# File 'lib/dnsimple/struct/certificate.rb', line 13

def contact_id
  @contact_id
end

#created_atString

Returns When the certificate was created in DNSimple.

Returns:

  • (String)

    When the certificate was created in DNSimple.



37
38
39
# File 'lib/dnsimple/struct/certificate.rb', line 37

def created_at
  @created_at
end

#csrString

Returns The certificate CSR.

Returns:

  • (String)

    The certificate CSR.



25
26
27
# File 'lib/dnsimple/struct/certificate.rb', line 25

def csr
  @csr
end

#domain_idInteger

Returns The associated domain ID.

Returns:

  • (Integer)

    The associated domain ID.



10
11
12
# File 'lib/dnsimple/struct/certificate.rb', line 10

def domain_id
  @domain_id
end

#expires_atString

Returns The timestamp when the certificate will expire.

Returns:

  • (String)

    The timestamp when the certificate will expire.



43
44
45
# File 'lib/dnsimple/struct/certificate.rb', line 43

def expires_at
  @expires_at
end

#idInteger

Returns The certificate ID in DNSimple.

Returns:

  • (Integer)

    The certificate ID in DNSimple.



7
8
9
# File 'lib/dnsimple/struct/certificate.rb', line 7

def id
  @id
end

#stateString

Returns The certificate state.

Returns:

  • (String)

    The certificate state.



28
29
30
# File 'lib/dnsimple/struct/certificate.rb', line 28

def state
  @state
end

#updated_atString

Returns When the certificate was last updated in DNSimple.

Returns:

  • (String)

    When the certificate was last updated in DNSimple.



40
41
42
# File 'lib/dnsimple/struct/certificate.rb', line 40

def updated_at
  @updated_at
end

#yearsInteger

Returns The years the certificate will last.

Returns:

  • (Integer)

    The years the certificate will last.



22
23
24
# File 'lib/dnsimple/struct/certificate.rb', line 22

def years
  @years
end