Class: Dnsimple::Struct::CertificatePurchase

Inherits:
Base
  • Object
show all
Defined in:
lib/dnsimple/struct/certificate_purchase.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#initialize

Constructor Details

This class inherits a constructor from Dnsimple::Struct::Base

Instance Attribute Details

#auto_renewBoolean

Returns True if the certificate is requested to auto-renew.

Returns:

  • (Boolean)

    True if the certificate is requested to auto-renew



16
17
18
# File 'lib/dnsimple/struct/certificate_purchase.rb', line 16

def auto_renew
  @auto_renew
end

#certificate_idInteger

Returns The certificate ID.

Returns:

  • (Integer)

    The certificate ID.



10
11
12
# File 'lib/dnsimple/struct/certificate_purchase.rb', line 10

def certificate_id
  @certificate_id
end

#created_atString

Returns When the certificate renewal was created in DNSimple.

Returns:

  • (String)

    When the certificate renewal was created in DNSimple.



19
20
21
# File 'lib/dnsimple/struct/certificate_purchase.rb', line 19

def created_at
  @created_at
end

#idInteger

Returns The certificate purchase ID in DNSimple.

Returns:

  • (Integer)

    The certificate purchase ID in DNSimple.



7
8
9
# File 'lib/dnsimple/struct/certificate_purchase.rb', line 7

def id
  @id
end

#stateString

Returns The certificate renewal state.

Returns:

  • (String)

    The certificate renewal state.



13
14
15
# File 'lib/dnsimple/struct/certificate_purchase.rb', line 13

def state
  @state
end

#updated_atString

Returns When the certificate renewal was last updated in DNSimple.

Returns:

  • (String)

    When the certificate renewal was last updated in DNSimple.



22
23
24
# File 'lib/dnsimple/struct/certificate_purchase.rb', line 22

def updated_at
  @updated_at
end