Class: Dnsimple::Struct::DelegationSignerRecord

Inherits:
Base
  • Object
show all
Defined in:
lib/dnsimple/struct/delegation_signer_record.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#initialize

Constructor Details

This class inherits a constructor from Dnsimple::Struct::Base

Instance Attribute Details

#algorithmString

Returns The signing algorithm used.

Returns:

  • (String)

    The signing algorithm used.



13
14
15
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 13

def algorithm
  @algorithm
end

#created_atString

Returns When the delegation signing record was created in DNSimple.

Returns:

  • (String)

    When the delegation signing record was created in DNSimple.



28
29
30
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 28

def created_at
  @created_at
end

#digestString

Returns The digest value.

Returns:

  • (String)

    The digest value.



16
17
18
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 16

def digest
  @digest
end

#digest_typeString

Returns The digest type used.

Returns:

  • (String)

    The digest type used.



19
20
21
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 19

def digest_type
  @digest_type
end

#domain_idInteger

Returns The associated domain ID.

Returns:

  • (Integer)

    The associated domain ID.



10
11
12
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 10

def domain_id
  @domain_id
end

#idInteger

Returns The ID of the delegation signer record in DNSimple.

Returns:

  • (Integer)

    The ID of the delegation signer record in DNSimple.



7
8
9
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 7

def id
  @id
end

#keytagString

Returns The keytag for the associated DNSKEY.

Returns:

  • (String)

    The keytag for the associated DNSKEY.



22
23
24
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 22

def keytag
  @keytag
end

#public_keyString

Returns The public key that references the corresponding DNSKEY record.

Returns:

  • (String)

    The public key that references the corresponding DNSKEY record.



25
26
27
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 25

def public_key
  @public_key
end

#updated_atString

Returns When the delegation signing record was last updated in DNSimple.

Returns:

  • (String)

    When the delegation signing record was last updated in DNSimple.



31
32
33
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 31

def updated_at
  @updated_at
end