Class: Dnsimple::Struct::Domain

Inherits:
Base
  • Object
show all
Defined in:
lib/dnsimple/struct/domain.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#initialize

Constructor Details

This class inherits a constructor from Dnsimple::Struct::Base

Instance Attribute Details

#account_idInteger

Returns The associated account ID.

Returns:

  • (Integer)

    The associated account ID.



10
11
12
# File 'lib/dnsimple/struct/domain.rb', line 10

def 
  @account_id
end

#auto_renewBool

Returns True if the domain is set to auto-renew, false otherwise.

Returns:

  • (Bool)

    True if the domain is set to auto-renew, false otherwise.



25
26
27
# File 'lib/dnsimple/struct/domain.rb', line 25

def auto_renew
  @auto_renew
end

#created_atString

Returns When the domain was created in DNSimple.

Returns:

  • (String)

    When the domain was created in DNSimple.



34
35
36
# File 'lib/dnsimple/struct/domain.rb', line 34

def created_at
  @created_at
end

#expires_atString

Returns The timestamp when domain will expire.

Returns:

  • (String)

    The timestamp when domain will expire.



31
32
33
# File 'lib/dnsimple/struct/domain.rb', line 31

def expires_at
  @expires_at
end

#idInteger

Returns The domain ID in DNSimple.

Returns:

  • (Integer)

    The domain ID in DNSimple.



7
8
9
# File 'lib/dnsimple/struct/domain.rb', line 7

def id
  @id
end

#nameString

Returns The domain name.

Returns:

  • (String)

    The domain name.



16
17
18
# File 'lib/dnsimple/struct/domain.rb', line 16

def name
  @name
end

#private_whoisBool

Returns True if the domain WHOIS privacy is enabled, false otherwise.

Returns:

  • (Bool)

    True if the domain WHOIS privacy is enabled, false otherwise.



28
29
30
# File 'lib/dnsimple/struct/domain.rb', line 28

def private_whois
  @private_whois
end

#registrant_idInteger

Returns The associated registrant (contact) ID.

Returns:

  • (Integer)

    The associated registrant (contact) ID.



13
14
15
# File 'lib/dnsimple/struct/domain.rb', line 13

def registrant_id
  @registrant_id
end

#stateString

Returns The domain state.

Returns:

  • (String)

    The domain state.



22
23
24
# File 'lib/dnsimple/struct/domain.rb', line 22

def state
  @state
end

#tokenString

Returns The domain API token used for domain authentication.

Returns:

  • (String)

    The domain API token used for domain authentication.



19
20
21
# File 'lib/dnsimple/struct/domain.rb', line 19

def token
  @token
end

#updated_atString

Returns When the domain was last updated in DNSimple.

Returns:

  • (String)

    When the domain was last updated in DNSimple.



37
38
39
# File 'lib/dnsimple/struct/domain.rb', line 37

def updated_at
  @updated_at
end