Class: Dnsimple::Struct::DomainPush
- Defined in:
- lib/dnsimple/struct/domain_push.rb
Instance Attribute Summary collapse
-
#accepted_at ⇒ String
When the domain push was accepted in DNSimple.
-
#account_id ⇒ Integer
The associated account ID.
-
#contact_id ⇒ Integer
The associated contact ID.
-
#created_at ⇒ String
When the domain push was created in DNSimple.
-
#domain_id ⇒ Integer
The associated domain ID.
-
#id ⇒ Integer
The domain push ID in DNSimple.
-
#updated_at ⇒ String
When the domain push was last updated in DNSimple.
Method Summary
Methods inherited from Base
Constructor Details
This class inherits a constructor from Dnsimple::Struct::Base
Instance Attribute Details
#accepted_at ⇒ String
Returns When the domain push was accepted in DNSimple.
25 26 27 |
# File 'lib/dnsimple/struct/domain_push.rb', line 25 def accepted_at @accepted_at end |
#account_id ⇒ Integer
Returns The associated account ID.
16 17 18 |
# File 'lib/dnsimple/struct/domain_push.rb', line 16 def account_id @account_id end |
#contact_id ⇒ Integer
Returns The associated contact ID.
13 14 15 |
# File 'lib/dnsimple/struct/domain_push.rb', line 13 def contact_id @contact_id end |
#created_at ⇒ String
Returns When the domain push was created in DNSimple.
19 20 21 |
# File 'lib/dnsimple/struct/domain_push.rb', line 19 def created_at @created_at end |
#domain_id ⇒ Integer
Returns The associated domain ID.
10 11 12 |
# File 'lib/dnsimple/struct/domain_push.rb', line 10 def domain_id @domain_id end |
#id ⇒ Integer
Returns The domain push ID in DNSimple.
7 8 9 |
# File 'lib/dnsimple/struct/domain_push.rb', line 7 def id @id end |
#updated_at ⇒ String
Returns When the domain push was last updated in DNSimple.
22 23 24 |
# File 'lib/dnsimple/struct/domain_push.rb', line 22 def updated_at @updated_at end |