Class: Dnsimple::Struct::DomainRenewal
- Defined in:
- lib/dnsimple/struct/domain_renewal.rb
Instance Attribute Summary collapse
-
#created_at ⇒ String
When the domain renewal was created in DNSimple.
-
#domain_id ⇒ Integer
The associated domain ID.
-
#id ⇒ Integer
The domain renewal ID in DNSimple.
-
#period ⇒ Integer
The number of years the domain was renewed for.
-
#state ⇒ String
The state of the renewal.
-
#updated_at ⇒ String
When the domain renewal was last updated in DNSimple.
Method Summary
Methods inherited from Base
Constructor Details
This class inherits a constructor from Dnsimple::Struct::Base
Instance Attribute Details
#created_at ⇒ String
Returns When the domain renewal was created in DNSimple.
19 20 21 |
# File 'lib/dnsimple/struct/domain_renewal.rb', line 19 def created_at @created_at end |
#domain_id ⇒ Integer
Returns The associated domain ID.
10 11 12 |
# File 'lib/dnsimple/struct/domain_renewal.rb', line 10 def domain_id @domain_id end |
#id ⇒ Integer
Returns The domain renewal ID in DNSimple.
7 8 9 |
# File 'lib/dnsimple/struct/domain_renewal.rb', line 7 def id @id end |
#period ⇒ Integer
Returns The number of years the domain was renewed for.
13 14 15 |
# File 'lib/dnsimple/struct/domain_renewal.rb', line 13 def period @period end |
#state ⇒ String
Returns The state of the renewal.
16 17 18 |
# File 'lib/dnsimple/struct/domain_renewal.rb', line 16 def state @state end |
#updated_at ⇒ String
Returns When the domain renewal was last updated in DNSimple.
22 23 24 |
# File 'lib/dnsimple/struct/domain_renewal.rb', line 22 def updated_at @updated_at end |