Class: Dnsimple::Struct::DomainResearchStatus

Inherits:
Base
  • Object
show all
Defined in:
lib/dnsimple/struct/domain_research_status.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#initialize

Constructor Details

This class inherits a constructor from Dnsimple::Struct::Base

Instance Attribute Details

#availabilityString

Returns:



13
14
15
# File 'lib/dnsimple/struct/domain_research_status.rb', line 13

def availability
  @availability
end

#domainString

Returns The domain name that was researched.

Returns:

  • (String)

    The domain name that was researched.



10
11
12
# File 'lib/dnsimple/struct/domain_research_status.rb', line 10

def domain
  @domain
end

#errorsArray<String>

Returns Array of error messages if the domain cannot be researched.

Returns:

  • (Array<String>)

    Array of error messages if the domain cannot be researched.



16
17
18
# File 'lib/dnsimple/struct/domain_research_status.rb', line 16

def errors
  @errors
end

#request_idString

Returns UUID identifier for this research request.

Returns:

  • (String)

    UUID identifier for this research request.



7
8
9
# File 'lib/dnsimple/struct/domain_research_status.rb', line 7

def request_id
  @request_id
end