Class: Dnsimple::Struct::DomainRestore
- Defined in:
- lib/dnsimple/struct/domain_restore.rb
Instance Attribute Summary collapse
-
#created_at ⇒ String
When the domain restore was created in DNSimple.
-
#domain_id ⇒ Integer
The associated domain ID.
-
#id ⇒ Integer
The domain restore ID in DNSimple.
-
#state ⇒ String
The state of the restore.
-
#updated_at ⇒ String
When the domain restore was last updated in DNSimple.
Method Summary
Methods inherited from Base
Constructor Details
This class inherits a constructor from Dnsimple::Struct::Base
Instance Attribute Details
#created_at ⇒ String
Returns When the domain restore was created in DNSimple.
16 17 18 |
# File 'lib/dnsimple/struct/domain_restore.rb', line 16 def created_at @created_at end |
#domain_id ⇒ Integer
Returns The associated domain ID.
10 11 12 |
# File 'lib/dnsimple/struct/domain_restore.rb', line 10 def domain_id @domain_id end |
#id ⇒ Integer
Returns The domain restore ID in DNSimple.
7 8 9 |
# File 'lib/dnsimple/struct/domain_restore.rb', line 7 def id @id end |
#state ⇒ String
Returns The state of the restore.
13 14 15 |
# File 'lib/dnsimple/struct/domain_restore.rb', line 13 def state @state end |
#updated_at ⇒ String
Returns When the domain restore was last updated in DNSimple.
19 20 21 |
# File 'lib/dnsimple/struct/domain_restore.rb', line 19 def updated_at @updated_at end |