Class: Dnsimple::Struct::EmailForward

Inherits:
Base
  • Object
show all
Defined in:
lib/dnsimple/struct/email_forward.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#initialize

Constructor Details

This class inherits a constructor from Dnsimple::Struct::Base

Instance Attribute Details

#activeBoolean

Returns True if the email forward is active, false otherwise.

Returns:

  • (Boolean)

    True if the email forward is active, false otherwise.



19
20
21
# File 'lib/dnsimple/struct/email_forward.rb', line 19

def active
  @active
end

#alias_emailString

Returns The receiving email recipient.

Returns:

  • (String)

    The receiving email recipient.



13
14
15
# File 'lib/dnsimple/struct/email_forward.rb', line 13

def alias_email
  @alias_email
end

#created_atString

Returns When the email forward was created in DNSimple.

Returns:

  • (String)

    When the email forward was created in DNSimple.



22
23
24
# File 'lib/dnsimple/struct/email_forward.rb', line 22

def created_at
  @created_at
end

#destination_emailString

Returns The email recipient the messages are delivered to.

Returns:

  • (String)

    The email recipient the messages are delivered to.



16
17
18
# File 'lib/dnsimple/struct/email_forward.rb', line 16

def destination_email
  @destination_email
end

#domain_idInteger

Returns The associated domain ID.

Returns:

  • (Integer)

    The associated domain ID.



10
11
12
# File 'lib/dnsimple/struct/email_forward.rb', line 10

def domain_id
  @domain_id
end

#idInteger

Returns The email forward ID in DNSimple.

Returns:

  • (Integer)

    The email forward ID in DNSimple.



7
8
9
# File 'lib/dnsimple/struct/email_forward.rb', line 7

def id
  @id
end

#updated_atString

Returns When the email forward was last updated in DNSimple.

Returns:

  • (String)

    When the email forward was last updated in DNSimple.



25
26
27
# File 'lib/dnsimple/struct/email_forward.rb', line 25

def updated_at
  @updated_at
end