Class: Dnsimple::Struct::RegistrantChangeCheck
- Defined in:
- lib/dnsimple/struct/registrant_change_check.rb
Instance Attribute Summary collapse
-
#contact_id ⇒ Integer
The associated contact ID.
-
#domain_id ⇒ Integer
The associated domain ID.
-
#extended_attributes ⇒ Array<Hash>
The extended attributes.
-
#registry_owner_change ⇒ Object
# @return [Boolean] True if the registrant change is a registry owner change.
Method Summary
Methods inherited from Base
Constructor Details
This class inherits a constructor from Dnsimple::Struct::Base
Instance Attribute Details
#contact_id ⇒ Integer
7 8 9 |
# File 'lib/dnsimple/struct/registrant_change_check.rb', line 7 def contact_id @contact_id end |
#domain_id ⇒ Integer
10 11 12 |
# File 'lib/dnsimple/struct/registrant_change_check.rb', line 10 def domain_id @domain_id end |
#extended_attributes ⇒ Array<Hash>
13 14 15 |
# File 'lib/dnsimple/struct/registrant_change_check.rb', line 13 def extended_attributes @extended_attributes end |
#registry_owner_change ⇒ Object
# @return [Boolean] True if the registrant change is a registry owner change.
16 17 18 |
# File 'lib/dnsimple/struct/registrant_change_check.rb', line 16 def registry_owner_change @registry_owner_change end |