Class: Dnsimple::Struct::ZoneRecord

Inherits:
Base
  • Object
show all
Defined in:
lib/dnsimple/struct/zone_record.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Base

#initialize

Constructor Details

This class inherits a constructor from Dnsimple::Struct::Base

Instance Attribute Details

#contentString



23
24
25
# File 'lib/dnsimple/struct/zone_record.rb', line 23

def content
  @content
end

#created_atString



38
39
40
# File 'lib/dnsimple/struct/zone_record.rb', line 38

def created_at
  @created_at
end

#idInteger



7
8
9
# File 'lib/dnsimple/struct/zone_record.rb', line 7

def id
  @id
end

#nameString



20
21
22
# File 'lib/dnsimple/struct/zone_record.rb', line 20

def name
  @name
end

#parent_idInteger

Deprecated.

The value is always nil, and the attribute will be removed in the next major version.

Returns The ID of the parent record, if this record is dependent on another record.



14
15
16
# File 'lib/dnsimple/struct/zone_record.rb', line 14

def parent_id
  @parent_id
end

#priorityInteger



29
30
31
# File 'lib/dnsimple/struct/zone_record.rb', line 29

def priority
  @priority
end

#regionsArray<String>



35
36
37
# File 'lib/dnsimple/struct/zone_record.rb', line 35

def regions
  @regions
end

#system_recordBool



32
33
34
# File 'lib/dnsimple/struct/zone_record.rb', line 32

def system_record
  @system_record
end

#ttlInteger



26
27
28
# File 'lib/dnsimple/struct/zone_record.rb', line 26

def ttl
  @ttl
end

#typeString



17
18
19
# File 'lib/dnsimple/struct/zone_record.rb', line 17

def type
  @type
end

#updated_atString



41
42
43
# File 'lib/dnsimple/struct/zone_record.rb', line 41

def updated_at
  @updated_at
end

#zone_idString



10
11
12
# File 'lib/dnsimple/struct/zone_record.rb', line 10

def zone_id
  @zone_id
end