Class: Dnsimple::Client
- Inherits:
-
Object
- Object
- Dnsimple::Client
- Defined in:
- lib/dnsimple/client.rb,
lib/dnsimple/client/tlds.rb,
lib/dnsimple/client/oauth.rb,
lib/dnsimple/client/zones.rb,
lib/dnsimple/client/billing.rb,
lib/dnsimple/client/clients.rb,
lib/dnsimple/client/domains.rb,
lib/dnsimple/client/accounts.rb,
lib/dnsimple/client/contacts.rb,
lib/dnsimple/client/identity.rb,
lib/dnsimple/client/services.rb,
lib/dnsimple/client/webhooks.rb,
lib/dnsimple/client/registrar.rb,
lib/dnsimple/client/templates.rb,
lib/dnsimple/client/certificates.rb,
lib/dnsimple/client/dns_analytics.rb,
lib/dnsimple/client/zones_records.rb,
lib/dnsimple/client/domains_dnssec.rb,
lib/dnsimple/client/domains_pushes.rb,
lib/dnsimple/client/services_domains.rb,
lib/dnsimple/client/templates_domains.rb,
lib/dnsimple/client/templates_records.rb,
lib/dnsimple/client/vanity_name_servers.rb,
lib/dnsimple/client/zones_distributions.rb,
lib/dnsimple/client/registrar_delegation.rb,
lib/dnsimple/client/domains_email_forwards.rb,
lib/dnsimple/client/registrar_auto_renewal.rb,
lib/dnsimple/client/registrar_transfer_lock.rb,
lib/dnsimple/client/registrar_whois_privacy.rb,
lib/dnsimple/client/registrar_registrant_changes.rb,
lib/dnsimple/client/domains_delegation_signer_records.rb
Overview
Client for the DNSimple API
Defined Under Namespace
Modules: Accounts, Billing, Certificates, Contacts, DnsAnalytics, Domains, DomainsDelegationSignerRecords, DomainsDnssec, DomainsEmailForwards, DomainsPushes, Identity, Oauth, Registrar, RegistrarAutoRenewal, RegistrarDelegation, RegistrarRegistrantChanges, RegistrarTransferLock, RegistrarWhoisPrivacy, Services, ServicesDomains, Templates, TemplatesDomains, TemplatesRecords, Tlds, VanityNameServers, Webhooks, Zones, ZonesDistributions, ZonesRecords Classes: AccountsService, BillingService, CertificatesService, ClientService, ContactsService, DnsAnalyticsService, DomainsService, IdentityService, OauthService, RegistrarService, ServicesService, TemplatesService, TldsService, VanityNameServersService, WebhooksService, ZonesService
Constant Summary collapse
- HEADER_AUTHORIZATION =
"Authorization"- API_VERSION =
Returns The current API version.
"v2"
Instance Attribute Summary collapse
-
#access_token ⇒ String
Domain API access token for authentication.
-
#domain_api_token ⇒ String
Domain API access token for authentication.
-
#password ⇒ String
DNSimple password for Basic Authentication.
-
#proxy ⇒ String?
Configure address:port values for proxy server.
-
#user_agent ⇒ String
Configure User-Agent header for requests.
-
#username ⇒ String
DNSimple username for Basic Authentication.
Class Method Summary collapse
-
.versioned(path) ⇒ String
Prepends the correct API version to
path.
Instance Method Summary collapse
-
#accounts ⇒ Dnsimple::Client::AccountsService
The account-related API proxy.
-
#base_url ⇒ String
Base URL for API requests.
-
#billing ⇒ Dnsimple::Client::BillingService
The billing-related API proxy.
-
#certificates ⇒ Dnsimple::Client::CertificatesService
The certificate-related API proxy.
-
#contacts ⇒ Dnsimple::Client::ContactsService
The contact-related API proxy.
-
#delete(path, data = nil, options = {}) ⇒ HTTParty::Response
Make a HTTP DELETE request.
-
#dns_analytics ⇒ Dnsimple::Client::DnsAnalyticsService
The DNS Analytics API proxy.
-
#domains ⇒ Dnsimple::Client::DomainsService
The domain-related API proxy.
-
#execute(method, path, data = nil, options = {}) ⇒ HTTParty::Response
Executes a request, validates and returns the response.
-
#get(path, options = {}) ⇒ HTTParty::Response
Make a HTTP GET request.
-
#identity ⇒ Dnsimple::Client::IdentityService
The identity-related API proxy.
-
#initialize(options = {}) ⇒ Client
constructor
A new instance of Client.
-
#oauth ⇒ Dnsimple::Client::OauthService
The oauth-related API proxy.
-
#patch(path, data = nil, options = {}) ⇒ HTTParty::Response
Make a HTTP PATCH request.
-
#post(path, data = nil, options = {}) ⇒ HTTParty::Response
Make a HTTP POST request.
-
#put(path, data = nil, options = {}) ⇒ HTTParty::Response
Make a HTTP PUT request.
-
#registrar ⇒ Dnsimple::Client::RegistrarService
The registrar-related API proxy.
-
#request(method, path, data = nil, options = {}) ⇒ HTTParty::Response
Make a HTTP request.
-
#services ⇒ Dnsimple::Client::ServicesService
The one-click-service-related API proxy.
-
#templates ⇒ Dnsimple::Client::TemplatesService
The templates-related API proxy.
-
#tlds ⇒ Dnsimple::Client::TldsService
The tld-related API proxy.
-
#vanity_name_servers ⇒ Dnsimple::Client::VanityNameServersService
The vanity-name-server-related API proxy.
-
#webhooks ⇒ Dnsimple::Client::WebhooksService
The webhooks-related API proxy.
-
#zones ⇒ Dnsimple::Client::ZonesService
The zone-related API proxy.
Constructor Details
#initialize(options = {}) ⇒ Client
Returns a new instance of Client.
69 70 71 72 73 74 75 76 77 |
# File 'lib/dnsimple/client.rb', line 69 def initialize( = {}) defaults = Dnsimple::Default. Dnsimple::Default.keys.each do |key| # rubocop:disable Style/HashEachMethods instance_variable_set(:"@#{key}", [key] || defaults[key]) end @services = {} end |
Instance Attribute Details
#access_token ⇒ String
Returns Domain API access token for authentication.
58 59 60 |
# File 'lib/dnsimple/client.rb', line 58 def access_token @access_token end |
#domain_api_token ⇒ String
Returns Domain API access token for authentication.
53 54 55 |
# File 'lib/dnsimple/client.rb', line 53 def domain_api_token @domain_api_token end |
#password ⇒ String
Returns DNSimple password for Basic Authentication.
48 49 50 |
# File 'lib/dnsimple/client.rb', line 48 def password @password end |
#proxy ⇒ String?
Returns Configure address:port values for proxy server.
66 67 68 |
# File 'lib/dnsimple/client.rb', line 66 def proxy @proxy end |
#user_agent ⇒ String
Returns Configure User-Agent header for requests.
62 63 64 |
# File 'lib/dnsimple/client.rb', line 62 def user_agent @user_agent end |
#username ⇒ String
Returns DNSimple username for Basic Authentication.
43 44 45 |
# File 'lib/dnsimple/client.rb', line 43 def username @username end |
Class Method Details
.versioned(path) ⇒ String
Prepends the correct API version to path.
35 36 37 |
# File 'lib/dnsimple/client.rb', line 35 def self.versioned(path) File.join(API_VERSION, path) end |
Instance Method Details
#accounts ⇒ Dnsimple::Client::AccountsService
Returns The account-related API proxy.
6 7 8 |
# File 'lib/dnsimple/client/clients.rb', line 6 def accounts @services[:accounts] ||= Client::AccountsService.new(self) end |
#base_url ⇒ String
Base URL for API requests.
It defaults to "https://api.dnsimple.com". For testing purposes use "https://api.sandbox.dnsimple.com".
98 99 100 |
# File 'lib/dnsimple/client.rb', line 98 def base_url Extra.join_uri(@base_url, "") end |
#billing ⇒ Dnsimple::Client::BillingService
Returns The billing-related API proxy.
11 12 13 |
# File 'lib/dnsimple/client/clients.rb', line 11 def billing @services[:billing] ||= Client::BillingService.new(self) end |
#certificates ⇒ Dnsimple::Client::CertificatesService
Returns The certificate-related API proxy.
16 17 18 |
# File 'lib/dnsimple/client/clients.rb', line 16 def certificates @services[:certificates] ||= Client::CertificatesService.new(self) end |
#contacts ⇒ Dnsimple::Client::ContactsService
Returns The contact-related API proxy.
21 22 23 |
# File 'lib/dnsimple/client/clients.rb', line 21 def contacts @services[:contacts] ||= Client::ContactsService.new(self) end |
#delete(path, data = nil, options = {}) ⇒ HTTParty::Response
Make a HTTP DELETE request.
147 148 149 |
# File 'lib/dnsimple/client.rb', line 147 def delete(path, data = nil, = {}) execute :delete, path, data, end |
#dns_analytics ⇒ Dnsimple::Client::DnsAnalyticsService
Returns The DNS Analytics API proxy.
31 32 33 |
# File 'lib/dnsimple/client/clients.rb', line 31 def dns_analytics @services[:dns_analytics] ||= Client::DnsAnalyticsService.new(self) end |
#domains ⇒ Dnsimple::Client::DomainsService
Returns The domain-related API proxy.
26 27 28 |
# File 'lib/dnsimple/client/clients.rb', line 26 def domains @services[:domains] ||= Client::DomainsService.new(self) end |
#execute(method, path, data = nil, options = {}) ⇒ HTTParty::Response
Executes a request, validates and returns the response.
162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/dnsimple/client.rb', line 162 def execute(method, path, data = nil, = {}) response = request(method, path, data, ) case response.code when 200..299 response when 401 raise AuthenticationFailed, response["message"] when 404 raise NotFoundError, response else raise RequestError, response end end |
#get(path, options = {}) ⇒ HTTParty::Response
Make a HTTP GET request.
108 109 110 |
# File 'lib/dnsimple/client.rb', line 108 def get(path, = {}) execute :get, path, nil, .to_h end |
#identity ⇒ Dnsimple::Client::IdentityService
Returns The identity-related API proxy.
36 37 38 |
# File 'lib/dnsimple/client/clients.rb', line 36 def identity @services[:auth] ||= Client::IdentityService.new(self) end |
#oauth ⇒ Dnsimple::Client::OauthService
Returns The oauth-related API proxy.
41 42 43 |
# File 'lib/dnsimple/client/clients.rb', line 41 def oauth @services[:oauth] ||= Client::OauthService.new(self) end |
#patch(path, data = nil, options = {}) ⇒ HTTParty::Response
Make a HTTP PATCH request.
138 139 140 |
# File 'lib/dnsimple/client.rb', line 138 def patch(path, data = nil, = {}) execute :patch, path, data, end |
#post(path, data = nil, options = {}) ⇒ HTTParty::Response
Make a HTTP POST request.
118 119 120 |
# File 'lib/dnsimple/client.rb', line 118 def post(path, data = nil, = {}) execute :post, path, data, end |
#put(path, data = nil, options = {}) ⇒ HTTParty::Response
Make a HTTP PUT request.
128 129 130 |
# File 'lib/dnsimple/client.rb', line 128 def put(path, data = nil, = {}) execute :put, path, data, end |
#registrar ⇒ Dnsimple::Client::RegistrarService
Returns The registrar-related API proxy.
46 47 48 |
# File 'lib/dnsimple/client/clients.rb', line 46 def registrar @services[:registrar] ||= Client::RegistrarService.new(self) end |
#request(method, path, data = nil, options = {}) ⇒ HTTParty::Response
Make a HTTP request.
This method doesn’t validate the response and never raise errors even in case of HTTP error codes, except for connection errors raised by the underlying HTTP client.
Therefore, it’s up to the caller to properly handle and validate the response.
190 191 192 193 194 195 196 197 198 199 |
# File 'lib/dnsimple/client.rb', line 190 def request(method, path, data = nil, = {}) = () if data [:headers]["Content-Type"] = content_type([:headers]) [:body] = content_data([:headers], data) end HTTParty.send(method, base_url + path, ) end |
#services ⇒ Dnsimple::Client::ServicesService
Returns The one-click-service-related API proxy.
51 52 53 |
# File 'lib/dnsimple/client/clients.rb', line 51 def services @services[:services] ||= Client::ServicesService.new(self) end |
#templates ⇒ Dnsimple::Client::TemplatesService
Returns The templates-related API proxy.
56 57 58 |
# File 'lib/dnsimple/client/clients.rb', line 56 def templates @services[:templates] ||= Client::TemplatesService.new(self) end |
#tlds ⇒ Dnsimple::Client::TldsService
Returns The tld-related API proxy.
61 62 63 |
# File 'lib/dnsimple/client/clients.rb', line 61 def tlds @services[:tlds] ||= Client::TldsService.new(self) end |
#vanity_name_servers ⇒ Dnsimple::Client::VanityNameServersService
Returns The vanity-name-server-related API proxy.
66 67 68 |
# File 'lib/dnsimple/client/clients.rb', line 66 def vanity_name_servers @services[:vanity_name_servers] ||= Client::VanityNameServersService.new(self) end |
#webhooks ⇒ Dnsimple::Client::WebhooksService
Returns The webhooks-related API proxy.
76 77 78 |
# File 'lib/dnsimple/client/clients.rb', line 76 def webhooks @services[:webhooks] ||= Client::WebhooksService.new(self) end |
#zones ⇒ Dnsimple::Client::ZonesService
Returns The zone-related API proxy.
71 72 73 |
# File 'lib/dnsimple/client/clients.rb', line 71 def zones @services[:zones] ||= Client::ZonesService.new(self) end |