Class: Dnsimple::Struct::DelegationSignerRecord
- Defined in:
- lib/dnsimple/struct/delegation_signer_record.rb
Instance Attribute Summary collapse
-
#algorithm ⇒ String
The signing algorithm used.
-
#created_at ⇒ String
When the delegation signing record was created in DNSimple.
-
#digest ⇒ String
The digest value.
-
#digest_type ⇒ String
The digest type used.
-
#domain_id ⇒ Integer
The associated domain ID.
-
#id ⇒ Integer
The ID of the delegation signer record in DNSimple.
-
#keytag ⇒ String
The keytag for the associated DNSKEY.
-
#public_key ⇒ String
The public key that references the corresponding DNSKEY record.
-
#updated_at ⇒ String
When the delegation signing record was last updated in DNSimple.
Method Summary
Methods inherited from Base
Constructor Details
This class inherits a constructor from Dnsimple::Struct::Base
Instance Attribute Details
#algorithm ⇒ String
Returns The signing algorithm used.
13 14 15 |
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 13 def algorithm @algorithm end |
#created_at ⇒ String
Returns When the delegation signing record was created in DNSimple.
28 29 30 |
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 28 def created_at @created_at end |
#digest ⇒ String
Returns The digest value.
16 17 18 |
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 16 def digest @digest end |
#digest_type ⇒ String
Returns The digest type used.
19 20 21 |
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 19 def digest_type @digest_type end |
#domain_id ⇒ Integer
Returns The associated domain ID.
10 11 12 |
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 10 def domain_id @domain_id end |
#id ⇒ Integer
Returns The ID of the delegation signer record in DNSimple.
7 8 9 |
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 7 def id @id end |
#keytag ⇒ String
Returns The keytag for the associated DNSKEY.
22 23 24 |
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 22 def keytag @keytag end |
#public_key ⇒ String
Returns The public key that references the corresponding DNSKEY record.
25 26 27 |
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 25 def public_key @public_key end |
#updated_at ⇒ String
Returns When the delegation signing record was last updated in DNSimple.
31 32 33 |
# File 'lib/dnsimple/struct/delegation_signer_record.rb', line 31 def updated_at @updated_at end |