Class: Dnsimple::Struct::Domain
- Defined in:
- lib/dnsimple/struct/domain.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Integer
The associated account ID.
-
#auto_renew ⇒ Bool
True if the domain is set to auto-renew, false otherwise.
-
#created_at ⇒ String
When the domain was created in DNSimple.
-
#expires_at ⇒ String
The timestamp when domain will expire.
-
#id ⇒ Integer
The domain ID in DNSimple.
-
#name ⇒ String
The domain name.
-
#private_whois ⇒ Bool
True if the domain WHOIS privacy is enabled, false otherwise.
-
#registrant_id ⇒ Integer
The associated registrant (contact) ID.
-
#state ⇒ String
The domain state.
-
#token ⇒ String
The domain API token used for domain authentication.
-
#updated_at ⇒ String
When the domain was last updated in DNSimple.
Method Summary
Methods inherited from Base
Constructor Details
This class inherits a constructor from Dnsimple::Struct::Base
Instance Attribute Details
#account_id ⇒ Integer
Returns The associated account ID.
10 11 12 |
# File 'lib/dnsimple/struct/domain.rb', line 10 def account_id @account_id end |
#auto_renew ⇒ Bool
Returns True if the domain is set to auto-renew, false otherwise.
25 26 27 |
# File 'lib/dnsimple/struct/domain.rb', line 25 def auto_renew @auto_renew end |
#created_at ⇒ String
Returns When the domain was created in DNSimple.
34 35 36 |
# File 'lib/dnsimple/struct/domain.rb', line 34 def created_at @created_at end |
#expires_at ⇒ String
Returns The timestamp when domain will expire.
31 32 33 |
# File 'lib/dnsimple/struct/domain.rb', line 31 def expires_at @expires_at end |
#id ⇒ Integer
Returns The domain ID in DNSimple.
7 8 9 |
# File 'lib/dnsimple/struct/domain.rb', line 7 def id @id end |
#name ⇒ String
Returns The domain name.
16 17 18 |
# File 'lib/dnsimple/struct/domain.rb', line 16 def name @name end |
#private_whois ⇒ Bool
Returns True if the domain WHOIS privacy is enabled, false otherwise.
28 29 30 |
# File 'lib/dnsimple/struct/domain.rb', line 28 def private_whois @private_whois end |
#registrant_id ⇒ Integer
Returns The associated registrant (contact) ID.
13 14 15 |
# File 'lib/dnsimple/struct/domain.rb', line 13 def registrant_id @registrant_id end |
#state ⇒ String
Returns The domain state.
22 23 24 |
# File 'lib/dnsimple/struct/domain.rb', line 22 def state @state end |
#token ⇒ String
Returns The domain API token used for domain authentication.
19 20 21 |
# File 'lib/dnsimple/struct/domain.rb', line 19 def token @token end |
#updated_at ⇒ String
Returns When the domain was last updated in DNSimple.
37 38 39 |
# File 'lib/dnsimple/struct/domain.rb', line 37 def updated_at @updated_at end |