Class: Dnsimple::Struct::EmailForward
- Defined in:
- lib/dnsimple/struct/email_forward.rb
Instance Attribute Summary collapse
-
#active ⇒ Boolean
True if the email forward is active, false otherwise.
-
#alias_email ⇒ String
The receiving email recipient.
-
#created_at ⇒ String
When the email forward was created in DNSimple.
-
#destination_email ⇒ String
The email recipient the messages are delivered to.
-
#domain_id ⇒ Integer
The associated domain ID.
-
#id ⇒ Integer
The email forward ID in DNSimple.
-
#updated_at ⇒ String
When the email forward was last updated in DNSimple.
Method Summary
Methods inherited from Base
Constructor Details
This class inherits a constructor from Dnsimple::Struct::Base
Instance Attribute Details
#active ⇒ Boolean
Returns True if the email forward is active, false otherwise.
19 20 21 |
# File 'lib/dnsimple/struct/email_forward.rb', line 19 def active @active end |
#alias_email ⇒ String
Returns The receiving email recipient.
13 14 15 |
# File 'lib/dnsimple/struct/email_forward.rb', line 13 def alias_email @alias_email end |
#created_at ⇒ String
Returns When the email forward was created in DNSimple.
22 23 24 |
# File 'lib/dnsimple/struct/email_forward.rb', line 22 def created_at @created_at end |
#destination_email ⇒ String
Returns The email recipient the messages are delivered to.
16 17 18 |
# File 'lib/dnsimple/struct/email_forward.rb', line 16 def destination_email @destination_email end |
#domain_id ⇒ Integer
Returns The associated domain ID.
10 11 12 |
# File 'lib/dnsimple/struct/email_forward.rb', line 10 def domain_id @domain_id end |
#id ⇒ Integer
Returns The email forward ID in DNSimple.
7 8 9 |
# File 'lib/dnsimple/struct/email_forward.rb', line 7 def id @id end |
#updated_at ⇒ String
Returns When the email forward was last updated in DNSimple.
25 26 27 |
# File 'lib/dnsimple/struct/email_forward.rb', line 25 def updated_at @updated_at end |