Class: Dnsimple::Struct::ZoneRecord
- Defined in:
- lib/dnsimple/struct/zone_record.rb
Instance Attribute Summary collapse
-
#content ⇒ String
The plain-text record content.
-
#created_at ⇒ String
When the record was created in DNSimple.
-
#id ⇒ Integer
The record ID in DNSimple.
-
#name ⇒ String
The record name (without the domain name).
-
#parent_id ⇒ Integer
deprecated
Deprecated.
The value is always nil, and the attribute will be removed in the next major version.
-
#priority ⇒ Integer
The priority value, if the type of record accepts a priority.
-
#regions ⇒ Array<String>
The regions where the record is propagated.
-
#system_record ⇒ Bool
True if this is a system record created by DNSimple.
-
#ttl ⇒ Integer
The TTL value.
-
#type ⇒ String
The type of record, in uppercase.
-
#updated_at ⇒ String
When the record was last updated in DNSimple.
-
#zone_id ⇒ String
The associated zone ID.
Method Summary
Methods inherited from Base
Constructor Details
This class inherits a constructor from Dnsimple::Struct::Base
Instance Attribute Details
#content ⇒ String
Returns The plain-text record content.
23 24 25 |
# File 'lib/dnsimple/struct/zone_record.rb', line 23 def content @content end |
#created_at ⇒ String
Returns When the record was created in DNSimple.
38 39 40 |
# File 'lib/dnsimple/struct/zone_record.rb', line 38 def created_at @created_at end |
#id ⇒ Integer
Returns The record ID in DNSimple.
7 8 9 |
# File 'lib/dnsimple/struct/zone_record.rb', line 7 def id @id end |
#name ⇒ String
Returns The record name (without the domain name).
20 21 22 |
# File 'lib/dnsimple/struct/zone_record.rb', line 20 def name @name end |
#parent_id ⇒ Integer
The value is always nil, and the attribute will be removed in the next major version.
Returns The ID of the parent record, if this record is dependent on another record.
14 15 16 |
# File 'lib/dnsimple/struct/zone_record.rb', line 14 def parent_id @parent_id end |
#priority ⇒ Integer
Returns The priority value, if the type of record accepts a priority.
29 30 31 |
# File 'lib/dnsimple/struct/zone_record.rb', line 29 def priority @priority end |
#regions ⇒ Array<String>
Returns The regions where the record is propagated. This is optional.
35 36 37 |
# File 'lib/dnsimple/struct/zone_record.rb', line 35 def regions @regions end |
#system_record ⇒ Bool
Returns True if this is a system record created by DNSimple. System records are read-only.
32 33 34 |
# File 'lib/dnsimple/struct/zone_record.rb', line 32 def system_record @system_record end |
#ttl ⇒ Integer
Returns The TTL value.
26 27 28 |
# File 'lib/dnsimple/struct/zone_record.rb', line 26 def ttl @ttl end |
#type ⇒ String
Returns The type of record, in uppercase.
17 18 19 |
# File 'lib/dnsimple/struct/zone_record.rb', line 17 def type @type end |
#updated_at ⇒ String
Returns When the record was last updated in DNSimple.
41 42 43 |
# File 'lib/dnsimple/struct/zone_record.rb', line 41 def updated_at @updated_at end |
#zone_id ⇒ String
Returns The associated zone ID.
10 11 12 |
# File 'lib/dnsimple/struct/zone_record.rb', line 10 def zone_id @zone_id end |